# -*- coding: utf-8 -*-
"""
@Author: HuangJianYi
@Date: 2021-09-16 19:14:40
@LastEditTime: 2023-06-01 13:44:08
@LastEditors: HuangJianYi
@Description: 
"""
#此文件由rigger自动生成
from seven_framework.mysql import MySQLHelper
from seven_framework.base_model import *
from seven_cloudapp_frame.models.cache_model import *


class PayOrderModel(CacheModel):
    def __init__(self, db_connect_key='db_cloudapp', sub_table=None, db_transaction=None, context=None):
        super(PayOrderModel, self).__init__(PayOrder, sub_table)
        self.db = MySQLHelper(config.get_value(db_connect_key))
        self.db_connect_key = db_connect_key
        self.db_transaction = db_transaction
        self.db.context = context

    #方法扩展请继承此类

class PayOrder:

    def __init__(self):
        super(PayOrder, self).__init__()
        self.id = 0  # id
        self.app_id = ""  # 应用标识
        self.act_id = 0  # 活动标识
        self.user_id = 0  # 用户标识
        self.open_id = ""  # open_id
        self.pay_order_no = ""  # 支付单号
        self.order_name = ""  # 订单名称
        self.order_desc = ""  # 订单描述
        self.source_type = 0  # 来源类型（1-购买2-邮费.业务自定义类型从101起，避免跟公共冲突）
        self.out_order_no = ""  # 平台交易单号
        self.order_status = 0  # 订单状态:0等待买家付款1付款成功2支付关闭11交易成功20退款关闭
        self.pay_amount = 0  # 支付金额（单位：元）
        self.discount_amount = 0  # 优惠金额（单位：元）
        self.refund_amount = 0  # 退款金额（单位：元）
        self.buy_num = 0  # 购买数量
        self.buy_object_id = ""  # 购买对象标识
        self.buy_object_name = ""  # 购买对象名称
        self.create_date = "1900-01-01 00:00:00"  # 创建时间
        self.pay_date = "1900-01-01 00:00:00"  # 支付时间
        self.process_count = 0 # 处理次数
        self.process_date = "1900-01-01 00:00:00"  # 处理时间
        self.remark = ""  # 备注

    @classmethod
    def get_field_list(self):
        return ['id', 'app_id', 'act_id', 'user_id', 'open_id', 'pay_order_no', 'order_name', 'order_desc', 'source_type', 'out_order_no', 'order_status', 'pay_amount', 'refund_amount', 'create_date', 'pay_date', 'process_count', 'process_date', 'remark']

    @classmethod
    def get_primary_key(self):
        return "id"

    def __str__(self):
        return "pay_order_tb"



# -*- coding: utf-8 -*-
"""
@Author: HuangJianYi
@Date: 2022-11-17 18:51:25
@LastEditTime: 2023-04-20 17:15:41
@LastEditors: HuangJianYi
@Description: 
"""
import hashlib
from seven_framework import *
from seven_cloudapp_frame.libs.common import *
from seven_cloudapp_frame.libs.customize.seven_helper import *
from seven_cloudapp_frame.models.seven_model import InvokeResultData

from baidubce.auth.bce_credentials import BceCredentials
from baidubce.bce_client_configuration import BceClientConfiguration
from baidubce.services.bos.bos_client import BosClient
from baidubce.services.bos import storage_class

class BaidubceHelper:
    """
    :description: 百度云帮助类
    """
    logger_error = Logger.get_logger_by_name("log_error")

    @classmethod
    def get_access_token(self):
        """
        :description:动态获取access_token
        :return: 
        :last_editors: HuangJianYi
        """
        api_key = share_config.get_value("baidubce_config", {}).get("text_censor", {}).get("api_key", "")
        secret_key = share_config.get_value("baidubce_config", {}).get("text_censor", {}).get("secret_key", "")
        request_url = f'https://aip.baidubce.com/oauth/2.0/token?grant_type=client_credentials&client_id={api_key}&client_secret={secret_key}'
        response = requests.get(request_url)
        if response:
            if "error" not in json.loads(response.text).keys():
                access_token = json.loads(response.text)["access_token"]
                redis_init = SevenHelper.redis_init(config_dict=config.get_value("platform_redis"))
                redis_init.set("baidu_access_token", access_token, ex=2591000)
                return access_token
            else:
                self.logger_error("【获取百度云access_token失败】" + response.text)
        return ""

    @classmethod
    def text_censor(self, text, conclusion_types = [1]):
        """
        :description: 百度云文本审核
        :param text：内容
        :param conclusion_types：允许审核通过的结果类型（1.合规，2.不合规，3.疑似，4.审核失败）
        :last_editors: HuangJianYi
        """
        invoke_result_data = InvokeResultData()
        access_token = SevenHelper.redis_init().get("baidu_access_token")
        if not access_token:
            access_token = self.get_access_token()
        if not access_token:
            invoke_result_data.success = False
            invoke_result_data.error_code = "fail_access_token"
            invoke_result_data.error_message = "无法进行文本审核"
            return invoke_result_data
        params = {"text": text}
        request_url = "https://aip.baidubce.com/rest/2.0/solution/v1/text_censor/v2/user_defined"
        request_url = request_url + "?access_token=" + access_token
        headers = {'content-type': 'application/x-www-form-urlencoded'}
        response = requests.post(request_url, data=params, headers=headers)
        if response:
            if "error_code" not in json.loads(response.text).keys():
                conclusion_type = response.json()["conclusionType"]
                if conclusion_type not in  conclusion_types:
                    invoke_result_data.success = False
                    invoke_result_data.error_code = "fail"
                    invoke_result_data.error_message = "存在敏感词"
                    return invoke_result_data
                invoke_result_data.data = conclusion_type
                return invoke_result_data
            else:
                self.logger_error("【百度云文本审核失败】" + response.text)
        invoke_result_data.success = False
        invoke_result_data.error_code = "fail"
        invoke_result_data.error_message = "无法进行文本审核"
        return invoke_result_data

    @classmethod
    def get_bos_client(self):
        """
        :description: 获取百度云存储对象的client客户端
        """
        baidubce_config = share_config.get_value("baidubce_config", {}).get("bos", {})
        access_key = baidubce_config.get("access_key", "")
        secret_key = baidubce_config.get("secret_key", "")
        end_point = baidubce_config.get("end_point", "")
        # 创建认证组
        credentials = BceCredentials(access_key_id=access_key, secret_access_key=secret_key)
        # 创建BceClientConfiguration
        config = BceClientConfiguration(credentials=credentials, endpoint=end_point)
        # 获取到客户端
        bos_client = BosClient(config=config)
        return bos_client

    @classmethod
    def context_md5(self, stream):
        md5 = hashlib.md5()
        md5.update(stream)
        content_md5 = base64.standard_b64encode(md5.digest())
        return content_md5

    @classmethod
    def put_object(self, file_name, stream):
        """
        :description:根据文件名上传到服务器
        :param file_name: 文件名
        :param stream: 二进制流
        :return: 
        :last_editors: HuangJianYi
        """
        bos_client = self.get_bos_client()
        baidubce_config = share_config.get_value("baidubce_config", {}).get("bos", {})
        folder = baidubce_config.get("folder", "")
        bucket = baidubce_config.get("bucket", "")
        domain = baidubce_config.get("domain", "")
        object_key = folder + "/" + str(int(time.time())) + str(uuid.uuid4()) + file_name
        # 根据文件名上传文件
        try:
            result = bos_client.put_object(bucket_name=bucket, key=object_key, data=stream, content_length=len(stream), content_md5=self.context_md5(stream), storage_class=storage_class.STANDARD)
            if result:
                return domain + "/" + object_key
        except Exception as e:
            self.logger_error("【上传文件出错】" + str(traceback.format_exc()))
        return ""

    @classmethod
    def put_object_from_file(self, file_name, local_file='', folder='', is_auto_name=True):
        """
        :description:根据文件名上传到服务器
        :param file_name: 文件名
        :param local_file: 本地文件地址
        :param folder: 文件夹
        :param is_auto_name: 是否生成随机文件名
        :return: 链接地址
        :last_editors: HuangJianYi
        """
        # 文件名
        file_name = os.path.basename(local_file) if local_file != "" else file_name
        if is_auto_name:
            file_extension = os.path.splitext(file_name)[1]
            file_name = UUIDHelper.get_uuid().replace("-", "") + file_extension
        bos_client = self.get_bos_client()
        baidubce_config = share_config.get_value("baidubce_config", {}).get("bos", {})
        if not folder:
            folder = baidubce_config.get("folder", "")
        bucket = baidubce_config.get("bucket", "")
        domain = baidubce_config.get("domain", "")
        object_key = folder + "/" + file_name
        try:
            result = bos_client.put_object_from_file(bucket_name=bucket, key=object_key, file_name=local_file)
            if result.status == 200:
                return domain + "/" + object_key
        except Exception as e:
            self.logger_error("【上传文件出错】" + str(traceback.format_exc()))
        return ""

    @classmethod
    def upload(self, file_name, is_auto_name=True, data=None):
        """
        :description:上传文件
        :param file_name：文件名称
        :param is_auto_name：是否生成随机文件名
        :param data：需要上传的数据
        :return: 
        :last_editors: HuangJianYi
        """
        if is_auto_name:
            file_extension = os.path.splitext(file_name)[1]
            file_name = UUIDHelper.get_uuid().replace("-", "") + file_extension
        return self.put_object(file_name, data)

    @classmethod
    def export_excel(self, import_data):
        """
        :description: 把数据导入excel并返回下载地址
        :param import_data:导入数据
        :return excel下载地址
        :last_editors: HuangJianYi
        """
        resource_path = ""
        if import_data:
            try:
                if not os.path.exists("temp"):
                    os.makedirs("temp")
                path = "temp/" + UUIDHelper.get_uuid() + ".xlsx"
                ExcelHelper.export(import_data, path)
                resource_path = self.put_object_from_file("", path, share_config.get_value("oss_folder"), False)
                os.remove(path)
            except Exception as ex:
                self.logger_error("【数据导入excel】" + traceback.format_exc())
        return resource_path
